@@ -117,6 +117,12 @@ AZURE_VOICES = [
         "Gender": "Female",
         "Locale": "en-GB"
     },
+    {
+        "Name": "Microsoft Server Speech Text to Speech Voice (en-GB, LibbyNeural)",
+        "ShortName": "en-GB-LibbyNeural",
+        "Gender": "Female",
+        "Locale": "en-GB"
+    },
     {
         "Name": "Microsoft Server Speech Text to Speech Voice (en-IE, Sean)",
         "ShortName": "en-IE-Sean",
@@ -226,20 +232,14 @@ AZURE_VOICES = [
         "Locale": "fr-CH"
     },
     {
-        "Name": "Microsoft Server Speech Text to Speech Voice (fr-FR, HortenseRUS)",
-        "ShortName": "fr-FR-HortenseRUS",
+        "Name": "Microsoft Server Speech Text to Speech Voice (fr-FR, DeniseNeural)",
+        "ShortName": "fr-FR-DeniseNeural",
         "Gender": "Female",
         "Locale": "fr-FR"
     },
     {
-        "Name": "Microsoft Server Speech Text to Speech Voice (fr-FR, Julie, Apollo)",
-        "ShortName": "fr-FR-Julie-Apollo",
-        "Gender": "Female",
-        "Locale": "fr-FR"
-    },
-    {
-        "Name": "Microsoft Server Speech Text to Speech Voice (fr-FR, Paul, Apollo)",
-        "ShortName": "fr-FR-Paul-Apollo",
+        "Name": "Microsoft Server Speech Text to Speech Voice (fr-FR, HenriNeural)",
+        "ShortName": "fr-FR-HenriNeural",
         "Gender": "Male",
         "Locale": "fr-FR"
     },
@@ -539,6 +539,7 @@ AZURE_VOICES = [
     }
 ]
 
+
 def find_voice(locale, gender, neural=True):
     """
     method to find voice
@@ -561,4 +562,4 @@ def find_voice(locale, gender, neural=True):
 
 
 # voice = find_voice(locale='en-US', gender='Female', neural=True)
-# print('found voice:', voice)
\ No newline at end of file
+# print('found voice:', voice)
